@@ -4,58 +4,46 @@
 <context>
     <name>Board</name>
     <message>
-        <location filename="../src/board.cpp" line="83"/>
-        <location filename="../src/board.cpp" line="872"/>
         <source>Details</source>
         <translation>Details</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="112"/>
         <source>Clear</source>
         <translation>Löschen</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="126"/>
         <source>Guess</source>
         <translation>Versuchen</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="156"/>
         <source>Found</source>
         <translation>Gefunden</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="295"/>
         <source>Normal</source>
         <translation>Normal</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="295"/>
         <source>Large</source>
         <translation>Groß</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="314"/>
         <source>Missed</source>
         <translation>Übersehen</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="448"/>
         <source>Error</source>
         <translation>Fehler</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="614"/>
         <source>Success</source>
         <translation>Richtig</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="614"/>
         <source>Game Over</source>
         <translation>Spiel beendet</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="793"/>
         <source>%1 of %n point(s)</source>
         <translation>
             <numerusform>%1 von %n Punkt</numerusform>
@@ -63,7 +51,6 @@
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="795"/>
         <source>3 of %n point(s)</source>
         <translation>
             <numerusform>3 von %n Punkt</numerusform>
@@ -71,7 +58,6 @@
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="797"/>
         <source>2 of %n point(s)</source>
         <translation>
             <numerusform>2 von %n Punkt</numerusform>
@@ -79,7 +65,6 @@
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="799"/>
         <source>1 of %n point(s)</source>
         <translation>
             <numerusform>1 von %n Punkt</numerusform>
@@ -87,7 +72,6 @@
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="801"/>
         <source>0 of %n point(s)</source>
         <translation>
             <numerusform>0 von %n Punkt</numerusform>
@@ -95,7 +79,6 @@
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="805"/>
         <source>%n point(s)</source>
         <translation>
             <numerusform>%n Punkt</numerusform>
@@ -103,7 +86,6 @@
         </translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="881"/>
         <source>The maximum score was calculated from the following thirty words:</source>
         <translation>Der Maximalscore wurde anhand der folgenden 30 Wörter berechnet:</translation>
     </message>
@@ -111,12 +93,10 @@
 <context>
     <name>Clock</name>
     <message>
-        <location filename="../src/clock.cpp" line="93"/>
         <source>m:ss</source>
         <translation>m:ss</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/clock.cpp" line="154"/>
         <source>%n guesses(s)</source>
         <translation>
             <numerusform>%n Versuch</numerusform>
@@ -124,12 +104,10 @@
         </translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="280"/>
         <source>+%1</source>
         <translation>+%1</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/clock.cpp" line="344"/>
         <source>%n strike(s)</source>
         <translation>
             <numerusform>%n Fehler</numerusform>
@@ -137,72 +115,58 @@
         </translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="519"/>
         <source>Tanglet</source>
         <translation>Tanglet</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="520"/>
         <source>Classic</source>
         <translation>Klassisch</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="521"/>
         <source>Refill</source>
         <translation>Zurücksetzen</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="522"/>
         <source>Stamina</source>
         <translation>Ausdauer</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="523"/>
         <source>Strikeout</source>
         <translation>Verlieren</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="524"/>
         <source>Allotment</source>
         <translation>Festanzahl</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="525"/>
         <source>Discipline</source>
         <translation>Disziplin</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="533"/>
         <source>Counts down from 30 seconds and increases on correct guesses.</source>
         <translation>Zählt von 30 Sekunden abwärts und erhöht bei richtigen Versuchen.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="534"/>
         <source>Counts down from 3 minutes.</source>
         <translation>Zählt von 3 Minuten abwärts.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="535"/>
         <source>Counts down from 30 seconds and refills on correct guesses.</source>
         <translation>Zählt von 30 Sekunden abwärts und setzt bei richtigen Versuchen zurück.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="536"/>
         <source>Counts down from 45 seconds and pauses on correct guesses.</source>
         <translation>Zählt von 45 Sekunden abwärts und pausiert bei richtigen Versuchen.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="537"/>
         <source>Game ends after 3 incorrect guesses.</source>
         <translation>Spiel endet nach 3 falschen Versuchen.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="538"/>
         <source>Game ends after 30 guesses.</source>
         <translation>Spiel endet nach 30 Versuchen.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="539"/>
         <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
         <translation>Zählt von 30 Sekunden abwärts und erhöht oder verringert bei Versuchen.</translation>
     </message>
@@ -210,132 +174,107 @@
 <context>
     <name>Generator</name>
     <message>
-        <location filename="../src/generator.cpp" line="273"/>
         <source>Unable to read dice from file.</source>
         <translation>Würfel konnte nicht aus Datei gelesen werden.</translation>
     </message>
     <message>
-        <location filename="../src/generator.cpp" line="351"/>
         <source>Unable to read word list from file.</source>
-        <translation>Wörterliste konnte nicht aus Datei gelesen werden.</translation>
+        <translation>Wortliste konnte nicht aus Datei gelesen werden.</translation>
     </message>
 </context>
 <context>
     <name>LanguageDialog</name>
     <message>
-        <location filename="../src/language_dialog.cpp" line="44"/>
         <source>Board Language</source>
         <translation>Spielfeldsprache</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="67"/>
         <source>Custom</source>
         <translation>Benutzerdefiniert</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="75"/>
-        <location filename="../src/language_dialog.cpp" line="82"/>
         <source>Choose...</source>
-        <translation>Auswählen...</translation>
+        <translation>Auswählen ...</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="91"/>
         <source>&lt;b&gt;Note:&lt;/b&gt; These settings will take effect when you start a new game.</source>
         <translation>&lt;b&gt;Hinweis:&lt;/b&gt; Diese Einstellungen werden nach dem Start eines neuen Spiels aktiv.</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="103"/>
         <source>Language:</source>
         <translation>Sprache:</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="106"/>
         <source>Dice:</source>
         <translation>Würfel:</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="110"/>
         <source>Word list:</source>
-        <translation>Wörterliste:</translation>
+        <translation>Wortliste:</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="114"/>
         <source>Dictionary:</source>
         <translation>Wörterbuch:</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="198"/>
         <source>Choose Dice File</source>
-        <translation>Würfel-Datei auswählen</translation>
+        <translation>Würfeldatei auswählen</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="214"/>
         <source>Choose Word List File</source>
-        <translation>Wörterlisten-Datei auswählen</translation>
+        <translation>Wortlistendatei auswählen</translation>
     </message>
 </context>
 <context>
     <name>LocaleDialog</name>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="52"/>
         <source>Select application language:</source>
         <translation>Anwendungssprache auswählen:</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="55"/>
         <source>&lt;System Language&gt;</source>
         <translation>&lt;Systemeinstellung&gt;</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="175"/>
         <source>Note</source>
         <translation>Hinweis</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="175"/>
         <source>Please restart this application for the change in language to take effect.</source>
-        <translation>Bitte starten Sie diese Anwendung neu um den Wechsel der Sprache auszuführen.</translation>
+        <translation>Bitte starten Sie diese Anwendung neu, um den Wechsel der Sprache auszuführen.</translation>
     </message>
 </context>
 <context>
     <name>NewGameDialog</name>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="81"/>
         <source>New Game</source>
         <translation>Neues Spiel</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="146"/>
         <source>Amount of Words:</source>
         <translation>Anzahl Wörter:</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="147"/>
         <source>Minimum Word Length:</source>
         <translation>Mindestwortlänge:</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="202"/>
         <source>Low</source>
         <translation>Niedrig</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="203"/>
         <source>Medium</source>
         <translation>Mittel</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="204"/>
         <source>High</source>
         <translation>Hoch</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="205"/>
         <source>Random</source>
         <translation>Zufällig</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/new_game_dialog.cpp" line="222"/>
         <source>%n letter(s)</source>
         <translation>
             <numerusform>%n Buchstabe</numerusform>
@@ -346,42 +285,34 @@
 <context>
     <name>ScoresDialog</name>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="52"/>
         <source>High Scores</source>
         <translation>Highscores</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="78"/>
         <source>&lt;b&gt;Name&lt;/b&gt;</source>
         <translation>&lt;b&gt;Name&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="79"/>
         <source>&lt;b&gt;Score&lt;/b&gt;</source>
         <translation>&lt;b&gt;Score&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="80"/>
         <source>&lt;b&gt;Date&lt;/b&gt;</source>
         <translation>&lt;b&gt;Datum&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="81"/>
         <source>&lt;b&gt;Timer&lt;/b&gt;</source>
         <translation>&lt;b&gt;Zeitlimit&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="85"/>
         <source>#%1</source>
         <translation>%1.</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="202"/>
         <source>Question</source>
         <translation>Frage</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="202"/>
         <source>Clear high scores?</source>
         <translation>Highscores löschen?</translation>
     </message>
@@ -389,312 +320,246 @@
 <context>
     <name>Window</name>
     <message>
-        <location filename="../src/main.cpp" line="32"/>
         <source>Tanglet</source>
         <translation>Tanglet</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="301"/>
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Paused&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Click to resume playing.&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Pausiert&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Zum Weiterspielen klicken.&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="307"/>
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Loading game...&lt;/p&gt;</source>
-        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Bitte warten&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Spiel wird geladen...&lt;/p&gt;</translation>
+        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Bitte warten&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Spiel wird geladen ...&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="312"/>
         <source>Click to start a new game.</source>
         <translation>Zum Start eines neuen Spiels klicken.</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="318"/>
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Generating a new board...&lt;/p&gt;</source>
-        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Bitte warten&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Neues Spielfeld wird generiert...&lt;/p&gt;</translation>
+        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Bitte warten&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Neues Spielfeld wird generiert ...&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="323"/>
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Optimizing word list...&lt;/p&gt;</source>
-        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Bitte warten&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Wörterliste wird optimiert...&lt;/p&gt;</translation>
+        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Bitte warten&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Wortliste wird optimiert ...&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="328"/>
         <source>&amp;Game</source>
         <translation>&amp;Spiel</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="329"/>
         <source>New &amp;Game...</source>
-        <translation>Ne&amp;ues Spiel...</translation>
+        <translation>Ne&amp;ues Spiel ...</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="329"/>
         <source>Ctrl+Shift+N</source>
         <translation>Ctrl+Shift+N</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="330"/>
         <source>&amp;New Roll</source>
         <translation>&amp;Neu würfeln</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="331"/>
         <source>&amp;Choose...</source>
-        <translation>I&amp;mportieren...</translation>
+        <translation>I&amp;mportieren ...</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="332"/>
         <source>&amp;Share...</source>
-        <translation>&amp;Exportieren...</translation>
+        <translation>&amp;Exportieren ...</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="334"/>
         <source>&amp;End</source>
         <translation>&amp;Spiel beenden</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="337"/>
         <source>&amp;Pause</source>
         <translation>&amp;Pausieren</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="339"/>
         <source>Ctrl+P</source>
         <translation>Ctrl+P</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="344"/>
         <source>&amp;Details</source>
         <translation>&amp;Details</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="346"/>
         <source>&amp;High Scores</source>
         <translation>&amp;Highscores</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="348"/>
         <source>&amp;Quit</source>
         <translation>&amp;Beenden</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="348"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="353"/>
         <source>&amp;Settings</source>
         <translation>&amp;Einstellungen</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="354"/>
         <source>Show &amp;Maximum Score</source>
         <translation>&amp;Maximale Punktzahl zeigen</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="356"/>
         <source>&amp;Never</source>
         <translation>&amp;Nie</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="357"/>
         <source>&amp;End Of Game</source>
         <translation>&amp;Spielende</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="358"/>
         <source>&amp;Always</source>
         <translation>I&amp;mmer</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="366"/>
         <source>Show Missed &amp;Words</source>
         <translation>Ü&amp;bersehene Wörter zeigen</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="369"/>
         <source>Show Word &amp;Counts</source>
         <translation>&amp;Wörterzahlen zeigen</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="373"/>
         <source>&amp;Board Language...</source>
-        <translation>&amp;Spielfeldsprache...</translation>
+        <translation>&amp;Spielfeldsprache ...</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="375"/>
         <source>Application &amp;Language...</source>
-        <translation>&amp;Anwendungssprache...</translation>
+        <translation>&amp;Anwendungssprache ...</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="379"/>
         <source>&amp;Help</source>
         <translation>&amp;Hilfe</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="380"/>
         <source>&amp;Controls</source>
         <translation>&amp;Steuerung</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="382"/>
         <source>&amp;About</source>
         <translation>Ü&amp;ber</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="384"/>
         <source>About &amp;Hspell</source>
         <translation>Über &amp;Hspell</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="386"/>
         <source>About &amp;Qt</source>
         <translation>Über &amp;Qt</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="388"/>
         <source>About &amp;SCOWL</source>
         <translation>Über &amp;SCOWL</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="470"/>
         <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
         <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="468"/>
         <source>Tanglet %1</source>
         <translation>Tanglet %1</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="466"/>
         <source>About</source>
         <translation>Über</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="469"/>
         <source>A single player variant of &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</source>
         <translation>Eine Einzelspielervariante von &lt;a href=&quot;http://de.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="471"/>
         <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
         <translation>Veröffentlicht unter der &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL-3&lt;/a&gt;-Lizenz</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="472"/>
         <source>English word list is based on &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; by Kevin Atkinson</source>
-        <translation>Englische Wörterliste basiert auf &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; von Kevin Atkinson</translation>
+        <translation>Englische Wortliste basiert auf &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; von Kevin Atkinson</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="473"/>
         <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
-        <translation>Hebräische Wörterliste basiert auf &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; von Nadav Har&apos;El und Dan Kenigsberg</translation>
+        <translation>Hebräische Wortliste basiert auf &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; von Nadav Har&apos;El und Dan Kenigsberg</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="480"/>
         <source>About Hspell</source>
         <translation>Über Hspell</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="487"/>
         <source>About SCOWL</source>
         <translation>Über SCOWL</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="516"/>
         <source>Import Game</source>
         <translation>Spiel importieren</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="518"/>
-        <location filename="../src/window.cpp" line="578"/>
         <source>Tanglet Games (*.tanglet)</source>
         <translation>Tanglet-Spiele (*.tanglet)</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="533"/>
-        <location filename="../src/window.cpp" line="548"/>
-        <location filename="../src/window.cpp" line="557"/>
-        <location filename="../src/window.cpp" line="787"/>
         <source>Unable to start requested game.</source>
         <translation>Gewähltes Spiel konnte nicht gestartet werden.</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="566"/>
-        <location filename="../src/window.cpp" line="787"/>
         <source>Error</source>
         <translation>Fehler</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="576"/>
         <source>Export Game</source>
         <translation>Spiel exportieren</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="623"/>
         <source>Question</source>
         <translation>Frage</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="623"/>
         <source>End the current game?</source>
         <translation>Gegenwärtiges Spiel abbrechen?</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="662"/>
         <source>Details</source>
         <translation>Details</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="668"/>
         <source>Board Size:</source>
         <translation>Spielfeldgröße:</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="668"/>
         <source>Normal</source>
         <translation>Normal</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="668"/>
         <source>Large</source>
         <translation>Groß</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="669"/>
         <source>Word Density:</source>
         <translation>Wörterdichte:</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="670"/>
         <source>Word Length:</source>
         <translation>Wortlänge:</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="670"/>
         <source>%1 or more letters</source>
         <translation>%1 oder mehr Buchstaben</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="671"/>
         <source>Game Type:</source>
         <translation>Spieltyp:</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="672"/>
         <source>Description:</source>
         <translation>Beschreibung:</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="702"/>
         <source>Controls</source>
         <translation>Steuerung</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="702"/>
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mit der Maus:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Wort auswählen:&lt;/b&gt; Auf die Buchstaben eines Worts klicken.&lt;br&gt;&lt;b&gt;Einen Versuch machen:&lt;/b&gt; Auf den zuletzt ausgewählten Buchstaben klicken.&lt;br&gt;&lt;b&gt;Buchstaben entfernen:&lt;/b&gt; Auf einen vorher ausgewählten Buchstaben klicken.&lt;br&gt;&lt;b&gt;Wort löschen:&lt;/b&gt; Zweimal auf den ersten ausgewählten Buchstaben klicken.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Mit der Tastatur:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Wort auswählen:&lt;/b&gt; Die Buchstaben eines Worts tippen.&lt;br&gt;&lt;b&gt;Einen Versuch machen:&lt;/b&gt; Eingabetaste drücken.&lt;br&gt;&lt;b&gt;Wort löschen:&lt;/b&gt; Strg+Backspace drücken.&lt;/p&gt;</translation>
     </message>
@@ -702,27 +567,22 @@
 <context>
     <name>WordCounts</name>
     <message>
-        <location filename="../src/word_counts.cpp" line="41"/>
         <source>Letters:</source>
         <translation>Buchstaben:</translation>
     </message>
     <message>
-        <location filename="../src/word_counts.cpp" line="41"/>
         <source>Found:</source>
         <translation>Gefunden:</translation>
     </message>
     <message>
-        <location filename="../src/word_counts.cpp" line="117"/>
         <source>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</source>
         <translation>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/word_counts.cpp" line="122"/>
         <source>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</source>
         <translation>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/word_counts.cpp" line="124"/>
         <source>%1&lt;br&gt;%2/%3</source>
         <translation>%1&lt;br&gt;%2/%3</translation>
     </message>
@@ -730,7 +590,6 @@
 <context>
     <name>WordTree</name>
     <message numerus="yes">
-        <location filename="../src/word_tree.cpp" line="93"/>
         <source>%n point(s)</source>
         <translation>
             <numerusform>%n Punkt</numerusform>
@@ -738,4 +597,15 @@
         </translation>
     </message>
 </context>
+<context>
+    <name>main</name>
+    <message>
+        <source>Word finding game</source>
+        <translation>Buchstabenrätsel</translation>
+    </message>
+    <message>
+        <source>A game file to play.</source>
+        <translation>Spieldatei zum Spielen.</translation>
+    </message>
+</context>
 </TS>
