@@ -601,11 +601,11 @@
     <name>main</name>
     <message>
         <source>Word finding game</source>
-        <translation type="unfinished"></translation>
+        <translation>Gioco di ricerca parole</translation>
     </message>
     <message>
         <source>A game file to play.</source>
-        <translation type="unfinished"></translation>
+        <translation>Un file gioco per giocare.</translation>
     </message>
 </context>
 </TS>
