@@ -4,100 +4,82 @@
 <context>
     <name>Board</name>
     <message>
-        <location filename="../src/board.cpp" line="83"/>
-        <location filename="../src/board.cpp" line="872"/>
         <source>Details</source>
         <translation>Perincian</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="112"/>
         <source>Clear</source>
         <translation>Kosongkan</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="126"/>
         <source>Guess</source>
         <translation>Teka</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="156"/>
         <source>Found</source>
         <translation>Temui</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="295"/>
         <source>Normal</source>
         <translation>Biasa</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="295"/>
         <source>Large</source>
         <translation>Besar</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="314"/>
         <source>Missed</source>
         <translation>Terlepas</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="448"/>
         <source>Error</source>
         <translation>Ralat</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="614"/>
         <source>Success</source>
         <translation>Berjaya</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="614"/>
         <source>Game Over</source>
         <translation>Permainan Tamat</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="793"/>
         <source>%1 of %n point(s)</source>
         <translation>
             <numerusform>%1 dari %n mata</numerusform>
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="795"/>
         <source>3 of %n point(s)</source>
         <translation>
             <numerusform>3 dari %n mata</numerusform>
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="797"/>
         <source>2 of %n point(s)</source>
         <translation>
             <numerusform>2 dari %n mata</numerusform>
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="799"/>
         <source>1 of %n point(s)</source>
         <translation>
             <numerusform>1 dari %n mata</numerusform>
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="801"/>
         <source>0 of %n point(s)</source>
         <translation>
             <numerusform>0 dari %n mata</numerusform>
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="805"/>
         <source>%n point(s)</source>
         <translation>
             <numerusform>%n mata</numerusform>
         </translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="881"/>
         <source>The maximum score was calculated from the following thirty words:</source>
         <translation>Skor maksimum telah dikira dari tiga pilih perkataan berikut:</translation>
     </message>
@@ -105,96 +87,78 @@
 <context>
     <name>Clock</name>
     <message>
-        <location filename="../src/clock.cpp" line="93"/>
         <source>m:ss</source>
         <translation>m:ss</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/clock.cpp" line="154"/>
         <source>%n guesses(s)</source>
         <translation>
             <numerusform>%n tekaan</numerusform>
         </translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="280"/>
         <source>+%1</source>
         <translation>+%1</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/clock.cpp" line="344"/>
         <source>%n strike(s)</source>
         <translation>
             <numerusform>%n percubaan</numerusform>
         </translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="519"/>
         <source>Tanglet</source>
         <translation>Tanglet</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="520"/>
         <source>Classic</source>
         <translation>Klasik</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="521"/>
         <source>Refill</source>
         <translation>Isian Semua</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="522"/>
         <source>Stamina</source>
         <translation>Stamina</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="523"/>
         <source>Strikeout</source>
         <translation>Strikeout</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="524"/>
         <source>Allotment</source>
         <translation>Pengumpukan</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="525"/>
         <source>Discipline</source>
         <translation>Disiplin</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="533"/>
         <source>Counts down from 30 seconds and increases on correct guesses.</source>
         <translation>Kiraan mengundur bermula dari 30 saat dan meningkat jika tekaan betul</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="534"/>
         <source>Counts down from 3 minutes.</source>
         <translation>Kiraan mengundur bermula dari 3 minit.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="535"/>
         <source>Counts down from 30 seconds and refills on correct guesses.</source>
         <translation>Kiraan mengundur bermula dari 30 saat dan diisi semula jika tekaan betul.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="536"/>
         <source>Counts down from 45 seconds and pauses on correct guesses.</source>
         <translation>Kiraan mengundur bermula dari 45 saat dan dijeda jika tekaan betul.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="537"/>
         <source>Game ends after 3 incorrect guesses.</source>
         <translation>Permainan tamat selepas 3 tekaan salah.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="538"/>
         <source>Game ends after 30 guesses.</source>
         <translation>Permainan tamat selepas 30 tekaan.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="539"/>
         <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
         <translation>Kiraan mengundur bermula dari 30 saat dan meningkat atau menurun mengikut tekaan.</translation>
     </message>
@@ -202,12 +166,10 @@
 <context>
     <name>Generator</name>
     <message>
-        <location filename="../src/generator.cpp" line="273"/>
         <source>Unable to read dice from file.</source>
         <translation>Tidak boleh baca dadu dari fail.</translation>
     </message>
     <message>
-        <location filename="../src/generator.cpp" line="351"/>
         <source>Unable to read word list from file.</source>
         <translation>Tidak boleh baca senarai perkataan dari fail.</translation>
     </message>
@@ -215,53 +177,42 @@
 <context>
     <name>LanguageDialog</name>
     <message>
-        <location filename="../src/language_dialog.cpp" line="44"/>
         <source>Board Language</source>
         <translation>Bahasa Papan</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="67"/>
         <source>Custom</source>
         <translation>Suai</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="75"/>
-        <location filename="../src/language_dialog.cpp" line="82"/>
         <source>Choose...</source>
         <translation>Pilih...</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="91"/>
         <source>&lt;b&gt;Note:&lt;/b&gt; These settings will take effect when you start a new game.</source>
         <translation>&lt;b&gt;Perhatian:&lt;/b&gt; Tetapan ini akan berkesan bila anda mulakan permainan baru.</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="103"/>
         <source>Language:</source>
         <translation>Bahasa:</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="106"/>
         <source>Dice:</source>
         <translation>Dadu:</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="110"/>
         <source>Word list:</source>
         <translation>Senarai perkataan:</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="114"/>
         <source>Dictionary:</source>
         <translation>Kamus:</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="198"/>
         <source>Choose Dice File</source>
         <translation>Pilih Fail Dadu</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="214"/>
         <source>Choose Word List File</source>
         <translation>Pilih Fail Senarai Perkataan</translation>
     </message>
@@ -269,22 +220,18 @@
 <context>
     <name>LocaleDialog</name>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="52"/>
         <source>Select application language:</source>
         <translation>Pilih bahasa aplikasi:</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="55"/>
         <source>&lt;System Language&gt;</source>
         <translation>&lt;Bahasa Sistem&gt;</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="175"/>
         <source>Note</source>
         <translation>Nota</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="175"/>
         <source>Please restart this application for the change in language to take effect.</source>
         <translation>Sila mulakan semula aplikasi ini supaya perubahan bahasa berkesan.</translation>
     </message>
@@ -292,42 +239,34 @@
 <context>
     <name>NewGameDialog</name>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="81"/>
         <source>New Game</source>
         <translation>Permainan Baru</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="146"/>
         <source>Amount of Words:</source>
         <translation>Amaun Perkataan:</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="147"/>
         <source>Minimum Word Length:</source>
         <translation>Panjangan Perkataan Minimum:</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="202"/>
         <source>Low</source>
         <translation>Rendah</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="203"/>
         <source>Medium</source>
         <translation>Sederhana</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="204"/>
         <source>High</source>
         <translation>Tinggi</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="205"/>
         <source>Random</source>
         <translation>Rawak</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/new_game_dialog.cpp" line="222"/>
         <source>%n letter(s)</source>
         <translation>
             <numerusform>%n abjad</numerusform>
@@ -337,42 +276,34 @@
 <context>
     <name>ScoresDialog</name>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="52"/>
         <source>High Scores</source>
         <translation>Skor Tertinggi</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="78"/>
         <source>&lt;b&gt;Name&lt;/b&gt;</source>
         <translation>&lt;b&gt;Nama&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="79"/>
         <source>&lt;b&gt;Score&lt;/b&gt;</source>
         <translation>&lt;b&gt;Skor&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="80"/>
         <source>&lt;b&gt;Date&lt;/b&gt;</source>
         <translation>&lt;b&gt;Tarikh&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="81"/>
         <source>&lt;b&gt;Timer&lt;/b&gt;</source>
         <translation>&lt;b&gt;Pemasa&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="85"/>
         <source>#%1</source>
         <translation>#%1</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="202"/>
         <source>Question</source>
         <translation>Soalan</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="202"/>
         <source>Clear high scores?</source>
         <translation>Kosongkan skor tertinggi?</translation>
     </message>
@@ -380,312 +311,246 @@
 <context>
     <name>Window</name>
     <message>
-        <location filename="../src/main.cpp" line="32"/>
         <source>Tanglet</source>
         <translation>Tanglet</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="301"/>
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Paused&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Click to resume playing.&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Dijeda&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Klik untuk sambung semula permainan.&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="307"/>
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Loading game...&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Tunggu sebentar&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Memuatkan permainan...&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="312"/>
         <source>Click to start a new game.</source>
         <translation>Klik untuk mulakan permainan baru.</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="318"/>
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Generating a new board...&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Tunggu sebentar&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Menjana papan baru...&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="323"/>
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Optimizing word list...&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Tunggu sebentar&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Mengoptimumkan senarai perkataan...&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="328"/>
         <source>&amp;Game</source>
         <translation>&amp;Permainan</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="329"/>
         <source>New &amp;Game...</source>
         <translation>&amp;Permainan Baru...</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="329"/>
         <source>Ctrl+Shift+N</source>
         <translation>Ctrl+Shift+N</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="330"/>
         <source>&amp;New Roll</source>
         <translation>Lempar &amp;Baru</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="331"/>
         <source>&amp;Choose...</source>
         <translation>P&amp;ilih...</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="332"/>
         <source>&amp;Share...</source>
         <translation>&amp;Kongsi...</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="334"/>
         <source>&amp;End</source>
         <translation>&amp;Tamat</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="337"/>
         <source>&amp;Pause</source>
         <translation>&amp;Jeda</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="339"/>
         <source>Ctrl+P</source>
         <translation>Ctrl+P</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="344"/>
         <source>&amp;Details</source>
         <translation>Perin&amp;cian</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="346"/>
         <source>&amp;High Scores</source>
         <translation>Skor &amp;Tertinggi</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="348"/>
         <source>&amp;Quit</source>
         <translation>&amp;Keluar</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="348"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="353"/>
         <source>&amp;Settings</source>
         <translation>T&amp;etapan</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="354"/>
         <source>Show &amp;Maximum Score</source>
         <translation>Tunjuk Skor &amp;Maksimum</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="356"/>
         <source>&amp;Never</source>
         <translation>Jan&amp;gan Sesekali</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="357"/>
         <source>&amp;End Of Game</source>
         <translation>&amp;Tamatkan Permainan</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="358"/>
         <source>&amp;Always</source>
         <translation>&amp;Sentiasa</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="366"/>
         <source>Show Missed &amp;Words</source>
         <translation>Tunjuk Pe&amp;rkataan Terlepas</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="369"/>
         <source>Show Word &amp;Counts</source>
         <translation>Tunjuk K&amp;iraan Perkataan</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="373"/>
         <source>&amp;Board Language...</source>
         <translation>Bahasa &amp;Papan...</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="375"/>
         <source>Application &amp;Language...</source>
         <translation>&amp;Bahasa Aplikasi...</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="379"/>
         <source>&amp;Help</source>
         <translation>Ba&amp;ntuan</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="380"/>
         <source>&amp;Controls</source>
         <translation>Ka&amp;walan</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="382"/>
         <source>&amp;About</source>
         <translation>Perih&amp;al</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="384"/>
         <source>About &amp;Hspell</source>
         <translation>Perihal &amp;Hspell</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="386"/>
         <source>About &amp;Qt</source>
         <translation>Perihal &amp;Qt</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="388"/>
         <source>About &amp;SCOWL</source>
         <translation>Perihal </translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="470"/>
         <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
         <translation>Hakcipta &amp;copy; 2009-%1 Graeme Gott</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="468"/>
         <source>Tanglet %1</source>
         <translation>Tanglet %1</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="466"/>
         <source>About</source>
         <translation>Perihal</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="469"/>
         <source>A single player variant of &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</source>
         <translation>Varian seorang pemain bagi permainan &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="471"/>
         <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
         <translation>Dikeluarkan dibawah lesen &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="472"/>
         <source>English word list is based on &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; by Kevin Atkinson</source>
         <translation>Senarai perkataan Bahasa Inggeris berasaskan pada &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; oleh Kevin Atkinson</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="473"/>
         <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
         <translation>Senarai perkataan Bahasa Ibrani berasaskan pada &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; oleh Nadav Har&apos;El dan Dan Kenigsberg</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="480"/>
         <source>About Hspell</source>
         <translation>Perihal Hspell</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="487"/>
         <source>About SCOWL</source>
         <translation>Perihal SCOWL</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="516"/>
         <source>Import Game</source>
         <translation>Import Permainan</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="518"/>
-        <location filename="../src/window.cpp" line="578"/>
         <source>Tanglet Games (*.tanglet)</source>
         <translation>Permaina Tanglet (*.tanglet)</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="533"/>
-        <location filename="../src/window.cpp" line="548"/>
-        <location filename="../src/window.cpp" line="557"/>
-        <location filename="../src/window.cpp" line="787"/>
         <source>Unable to start requested game.</source>
         <translation>Tidak boleh mulakan permainan yang diminta.</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="566"/>
-        <location filename="../src/window.cpp" line="787"/>
         <source>Error</source>
         <translation>Ralat</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="576"/>
         <source>Export Game</source>
         <translation>Eksport Permainan</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="623"/>
         <source>Question</source>
         <translation>Soalan</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="623"/>
         <source>End the current game?</source>
         <translation>Tamatkan permainan semasa?</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="662"/>
         <source>Details</source>
         <translation>Perincian</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="668"/>
         <source>Board Size:</source>
         <translation>Saiz Papan:</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="668"/>
         <source>Normal</source>
         <translation>Biasa</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="668"/>
         <source>Large</source>
         <translation>Besar</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="669"/>
         <source>Word Density:</source>
         <translation>Kepadatan Perkataan:</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="670"/>
         <source>Word Length:</source>
         <translation>Panjang Perkataan:</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="670"/>
         <source>%1 or more letters</source>
         <translation>%1 atau lebih abjad</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="671"/>
         <source>Game Type:</source>
         <translation>Jenis Permainan:</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="672"/>
         <source>Description:</source>
         <translation>Keterangan:</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="702"/>
         <source>Controls</source>
         <translation>Kawalan</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="702"/>
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Main Menggunakan Tetikus:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Pilih perkataan:&lt;/b&gt; Klik pada abjad perkataan.&lt;br&gt;&lt;b&gt;Buat tekaan:&lt;/b&gt; Klik pada abjad terpilih yang terakhir.&lt;br&gt;&lt;b&gt;Padam abjad:&lt;/b&gt; Klik pada abjad terpilih yang awal.&lt;br&gt;&lt;b&gt;Kosongkan perkataan:&lt;/b&gt; Klik dua kali pada abjad terpilih yang pertama.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Main Menggunakan Papan Kekunci:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Pilih perkataan:&lt;/b&gt; Taip abjad perkataan tersebut.&lt;br&gt;&lt;b&gt;Buat tekaan:&lt;/b&gt; Tekan Enter.&lt;br&gt;&lt;b&gt;Kosongkan perkataan:&lt;/b&gt; Tekan Ctrl+Backspace.&lt;/p&gt;</translation>
     </message>
@@ -693,27 +558,22 @@
 <context>
     <name>WordCounts</name>
     <message>
-        <location filename="../src/word_counts.cpp" line="41"/>
         <source>Letters:</source>
         <translation>Abjad:</translation>
     </message>
     <message>
-        <location filename="../src/word_counts.cpp" line="41"/>
         <source>Found:</source>
         <translation>Temui:</translation>
     </message>
     <message>
-        <location filename="../src/word_counts.cpp" line="117"/>
         <source>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</source>
         <translation>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/word_counts.cpp" line="122"/>
         <source>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</source>
         <translation>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/word_counts.cpp" line="124"/>
         <source>%1&lt;br&gt;%2/%3</source>
         <translation>%1&lt;br&gt;%2/%3</translation>
     </message>
@@ -721,11 +581,21 @@
 <context>
     <name>WordTree</name>
     <message numerus="yes">
-        <location filename="../src/word_tree.cpp" line="93"/>
         <source>%n point(s)</source>
         <translation>
             <numerusform>%n mata</numerusform>
         </translation>
     </message>
 </context>
+<context>
+    <name>main</name>
+    <message>
+        <source>Word finding game</source>
+        <translation>Permainan mencari perkataan</translation>
+    </message>
+    <message>
+        <source>A game file to play.</source>
+        <translation>Fail permainan untuk main.</translation>
+    </message>
+</context>
 </TS>
